==> haskell-conversion-1.2.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conversion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 conversion
version:              1.2.1
visibility:           public
id:                   conversion-1.2.1-9p0SxcW9MWL38uSZ9tx2XT
key:                  conversion-1.2.1-9p0SxcW9MWL38uSZ9tx2XT
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/conversion
synopsis:             Universal converter between values of different types
category:             Control, Data, Conversion
abi:                  a816fb3449617a4f597af6d820d5b458
exposed:              True
exposed-modules:      Conversion
import-dirs:          /usr/lib/ghc-8.8.3/site-local/conversion-1.2.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/conversion-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/conversion-1.2.1
hs-libraries:         HSconversion-1.2.1-9p0SxcW9MWL38uSZ9tx2XT
depends:              base-prelude-1.3-GkjcM0d5Bef5VOhNpPY6Ft
haddock-interfaces:   /usr/share/doc/haskell-conversion/html/conversion.haddock
haddock-html:         /usr/share/doc/haskell-conversion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conversion-1.2.1-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conversion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 conversion
version:              1.2.1
visibility:           public
id:                   conversion-1.2.1-INPo3L8nFn9F7Cohd4k8GT
key:                  conversion-1.2.1-INPo3L8nFn9F7Cohd4k8GT
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/conversion 
synopsis:             Universal converter between values of different types
category:             Control, Data, Conversion
abi:                  480b0e63bbd8fa32d8df3048490ea843
exposed:              True
exposed-modules:      Conversion
import-dirs:          /usr/lib/ghc-8.10.1/site-local/conversion-1.2.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/conversion-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/conversion-1.2.1
hs-libraries:         HSconversion-1.2.1-INPo3L8nFn9F7Cohd4k8GT
depends:              base-prelude-1.3-I8Q05mVZ6da5V9ORp5dnoi
haddock-interfaces:   /usr/share/doc/haskell-conversion/html/conversion.haddock
haddock-html:         /usr/share/doc/haskell-conversion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
